# -*- coding: utf-8 -*-
"""
Created on Thu Nov 05 10:19:59 2015

@author: Eric

This script is used for post-processing of EMA3D simulation probes.
"""

import glob, time, shutil
import matplotlib.pyplot as plt
from matplotlib import rc
import numpy as np
import re
import os
 #the following section includes some definitions from my personal python package:
def searchdir(direc,kind,lis):
    names=glob.glob(direc)
    for item in names:
        if item.endswith(kind):
            lis.append(item)
        elif os.path.isdir(item):
            searchdir(item+"\\*",kind,lis)
            
def filen(string):
    temp=string.rsplit("\\",1)
    return temp[1]
    
class MyStr(object):
    def __init__(self, text):
        self.prnt = text
    def __sub__(self, other):
#		temp=str(self.prnt)
        if self.prnt.count(other) > 0:
            return self.prnt.replace(other, '', 1)
        else:
            return self.prnt
    
rc('font',**{'family':'sans-serif','sans-serif':['Helvetica']})
tex = False
if shutil.which('latex'):
    tex = True
rc('text', usetex=tex)


def organize(filelist,curlis,voltlist):
    curexp = re.compile(r"\S+bpr[0-9]+\S+")
    volexp = re.compile(r"\S+nprnumertime[0-9]+\S+")
    for name in filelist:
        if curexp.search(name):
            curlis.append(name)
        elif volexp.search(name):
            voltlist.append(name)

def curdata(lis,tstep):
    flag=0
    maxj=max(lis)
    minj=min(lis)
    if abs(minj)>=maxj:
        maximum=minj
    else:
        maximum=maxj
    maxi=lis.tolist().index(maximum)
    maxt=(maxi+1)*tstep
    for i in range(len(lis)):
        if i>=maxi and flag==0 and abs(lis[i])<=abs(maximum)/2:
            flag=1
            half=(i+1)*tstep
        elif flag==0:
            half='N/A'
    return maximum,maxt,half
            
        
def voltdata(lis,tstep):
    maxv=max(lis)
    minv=min(lis)
    if abs(minv)>=maxv:
        maximum=minv
    else:
        maximum=maxv
    maxind=lis.tolist().index(maximum)
    maxt=(maxind+1)*tstep
    flag=0
    for i in range(len(lis)):
        if i>=maxind and flag==0 and abs(lis[i])<=abs(maximum)/2:
            flag=1
            half=(i+1)*tstep
        elif flag==0:
            half= 'N/A'
    return maximum,maxt,half

labelfile=input("Enter the file name (with full path) to the csv holding the labels. \n")
with open(labelfile,'r') as labels:
    thing=labels.read()

thing2=thing.split('\n')
nice=[]
for row in thing2:
    temp=row.split(',')
    nice.append(temp)
    
nice.sort(key=lambda x: x)

curexp = re.compile(r"bpr[0-9]+")
volexp = re.compile(r"nprnumertime[0-9]+")
curnames=[]
volnames=[]
for row in nice:
    if curexp.search(row[0]):
        curnames.append(row)
    elif volexp.search(row[0]):
        volnames.append(row)

filelist=[]
directory=input("Enter the directory to search for .dat files. \n")
starttime=time.time()

os.chdir(directory)
searchdir(directory,"dat",filelist)


curprobes=[]
voltprobes=[]


organize(filelist,curprobes,voltprobes)
curprobes.sort()
voltprobes.sort()
suffix=r".png"
i=0

currenttable=[['Probe','Description','Max Current (A)','Peak Time (S)','Half Peak Time (S)']]
for datafile in curprobes:
    data=np.loadtxt(datafile)
    #make time data in microseconds
    datat=data[:,0]*1e6
    dataj=data[:,1]
    #calculate time step
    tstep=data[1,0]-data[0,0]
    #make summary table row for probe:
    summary=curdata(dataj,tstep)
    tableout=curnames[i]
    for value in summary:
        tableout.append(str(value))
    currenttable.append(tableout)
    #find maxes and mins for plot axes
    minj=min(dataj)
    maxj=max(dataj)
    #plot and format:
    fig=plt.figure()
    plt.plot(datat,dataj)
    plt.grid(True)
    plt.title(curnames[i][1],fontsize=16)
    plt.xlabel(r'Time ($\mu s$)')
    plt.ylabel('Current (A)')
#    plt.show()
    plt.ylim((1.1*minj,1.1*maxj))
    #find basename of file and save:
    probename=filen(datafile)
    basename=MyStr(probename)-".dat"
    fullname=directory+"\\"+str(basename)+suffix
    plt.savefig(fullname,dpi=160)
    plt.close()
    i+=1


volttable=[['Probe','Description','Max Voltage (V)','Peak Time (S)','Half Peak Time (S)']]
i=0
for datafile in voltprobes:
    data=np.loadtxt(datafile)
    datat=data[:,0]*1e6
    #enter the cell size in meters
    cellsize=0.025
    dataV=data[:,1]*cellsize
    minV=min(dataV)
    maxV=max(dataV)
    tstep=data[1,0]-data[0,0]
    summary=voltdata(dataV,tstep)
    tableout=volnames[i]
    for value in summary:
        tableout.append(str(value))
    volttable.append(tableout)
    fig=plt.figure()
    plt.plot(datat,dataV)
    plt.grid(True)
    plt.title(volnames[i][1],fontsize=16)
    plt.xlabel(r'Time ($\mu s$)')
    plt.ylabel('Voltage (V)')
    basenamev=MyStr(filen(datafile))-".dat"
    fullname=directory+"\\"+str(basenamev)+suffix
    plt.ylim((1.1*minV,1.1*maxV))
    plt.savefig(fullname,dpi=160)
    plt.close()
    i+=1
    
    
with open(directory+r'\current_summary.txt','w') as curtab:
    for line in currenttable:
        curtab.write("\t".join(line)+"\n")

with open(directory+r'\voltage_summary.txt','w') as voltab:
    for line in volttable:
        voltab.write("\t".join(line)+"\n")

totaltime=time.time()-starttime
print(totaltime)
