# -*- coding: utf-8 -*-
"""
Created on Fri Feb 26 14:04:38 2016

@author: Eric Miller

This script plots and displays a single CURRENT (bpr#) probe output from an
EMA3D simulation. This version requires that the filename and plot title be
edited inside the .py file.
"""

import numpy as np
import matplotlib.pyplot as plt

# between the quotation marks, enter the file name of the .dat file to process 
filename=r"basic_plane2bpr2.dat"

#Enter a plot title:
title="Right Wing Current"

#load the data from the file
data = np.loadtxt(filename)

#assign time values and convert to microseconds
datat=data[:,0]*1e6

#assign current values
dataj=data[:,1]

#identify timestep by comparing successive times
tstep=data[1,0]-data[0,0]

#find the maximimum and minimum current values to use as bounds of the plot
minj=min(dataj)
maxj=max(dataj)

#plot the data
fig=plt.figure()
plt.plot(datat,dataj)
plt.grid(True)
plt.title(title,fontsize=16)
plt.xlabel(r'Time (us)')
plt.ylabel('Current (A)')
fullname=title+r'.png'
plt.ylim((1.1*minj,1.1*maxj))
plt.savefig(fullname,dpi=160)
plt.show()
#plt.close()
